@@ -1,3 +1,4 @@
+import sys
 from six.moves.urllib.parse import urljoin as sys_urljoin
 from functools import reduce
 
@@ -13,3 +14,12 @@ def get_json(request):
     else:
         return request.json
 
+def encode_utf8(u):
+    if sys.version_info[0] == 2:
+        u = u.encode('utf-8')
+    return u
+
+def decode_utf8(u):
+    if sys.version_info[0] == 2:
+        u = u.decode('utf-8')
+    return u
